@@ -411,21 +411,21 @@ def send_email(destinations, subject, message, attachment=None):
         destinations = list(destinations)
     content = MIMEText(message, 'plain', 'utf-8')
 
-    if attachment:
-        msg = MIMEMultipart('related')
-        attachment = MIMEBase('text', 'csv')
-        msg.attach(attachment)
-        fp = open('/tmp/details_reconciliation.csv', 'rb')
-        attachment.set_payload(fp.read())
-        fp.close()
-        attachment.add_header(
-            'Content-Disposition',
-            'attachment',
-            filename='details_reconciliation.csv'
-        )
-    else:
-        msg = MIMEMultipart()
-
+    # if attachment:
+    #     msg = MIMEMultipart('related')
+    #     attachment = MIMEBase('text', 'csv')
+    #     msg.attach(attachment)
+    #     fp = open('/tmp/details_reconciliation.csv', 'rb')
+    #     attachment.set_payload(fp.read())
+    #     fp.close()
+    #     attachment.add_header(
+    #         'Content-Disposition',
+    #         'attachment',
+    #         filename='details_reconciliation.csv'
+    #     )
+    # else:
+    #     msg = MIMEMultipart()
+    msg = MIMEMultipart()
     msg['Subject'] = subject
     msg['From'] = sender
     msg['To'] = ', '.join(destinations)
