@@ -70,6 +70,10 @@ class Product_GP(object):
             auth=(username, ''),
             json={'type': product_type}
             )
+        LOGS.logger.info(
+            "Fetching all customers information from Bluebase: {}"
+            .format(response)
+        )
         if response.status_code == 200:
             response = response.json()
             data = response['root']['data']
@@ -95,7 +99,12 @@ class Product_GP(object):
                     }
                 if product_type == 'try_airfiber':
                     kwargs['date_try'] = info['try_af_datefin']
+
                 result.append(Product_GP(name, ident, **kwargs))
+            LOGS.logger.info(
+                "Customers information from Bluebase summary: {}"
+                .format(result)
+            )
             return result
 
     def consumption(self, start_date, stop_date):
@@ -104,8 +113,10 @@ class Product_GP(object):
             start_date = (datetime.now() - timedelta(30))
         if not stop_date:
             stop_date = (datetime.now() - timedelta(1))
-        LOGS.logger.info(start_date)
-        LOGS.logger.info(stop_date)
+        msg = (
+            "Consommations du client des 30 derniers jours ({} au {}): "
+            .format(start_date, stop_date)
+        )
         url = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
             eng=CONFIG['CDRDATA']['engine'],
             user=CONFIG['CDRDATA']['username'],
@@ -133,6 +144,7 @@ class Product_GP(object):
                         value = 0
                     else:
                         value = float(value)
+                    LOGS.logger.info(msg + value)
                     return float(value)
         elif self.type_ident == 'mac':
             with records.Database(url) as db:
@@ -153,6 +165,7 @@ class Product_GP(object):
                         value = 0
                     else:
                         value = float(value)
+                    LOGS.logger.info(msg + value)
                     return float(value)
         elif self.type_ident == 'ident':
             consos = self.details_consumption_notif(self.ident)
@@ -160,11 +173,11 @@ class Product_GP(object):
                 float(i['total_for_fup_HO'])
                 for i in consos
                 ])
-            LOGS.logger.info(value)
+            LOGS.logger.info(msg + value)
             return float(value)
 
         else:
-            LOGS.logger.warn('Error identifiant non definie')
+            LOGS.logger.error("Identifiant du client manquant")
             return 0.0
 
     def details_consumption_notif(self, client_name):
@@ -230,6 +243,9 @@ class Product_GP(object):
             msg.as_string()
             )
         s.quit()
+        LOGS.logger.info(
+            "Email sent to {}: {}".format(msg['To'], msg['Subject'])
+        )
         REDIS_DB.hmset(
             '{}:{}'.format(key, tag),
             {
@@ -267,6 +283,9 @@ class Product_GP(object):
                 'msisdn': phonenumber
                 }
             )
+        LOGS.logger.info(
+            "SMS sent to {}: {}".format(phonenumber, sms)
+        )
         REDIS_DB.hmset(
             '{}:{}'.format(key, tag),
             {
@@ -426,6 +445,10 @@ class Product_GP(object):
                         self.limit,
                         remaining_seconds
                         )
+                    LOGS.logger.info(
+                        "Email sent to {}: {}".format(self.email, obj)
+                    )
+
                     """content = MIMEText(message, 'plain', 'utf-8')
                     msg = MIMEMultipart()
                     msg['Subject'] = ('[blueline] {object}').format(object=obj)
@@ -490,6 +513,9 @@ class Product_GP(object):
                             self.limit,
                             remaining_seconds
                             )
+                        LOGS.logger.info(
+                            "SMS sent to {}: {}".format(self.phonenumber, sms)
+                        )
                         """requests.post(
                             url='https://{fqdn}/smsc/v1/sms'.format(
                                 fqdn=APIGW
